@@ -1,6 +1,5 @@
 module Main where
 
-import Data.Maybe (catMaybes)
 import Text.Email.Validate
 import Test.HUnit
 
@@ -20,18 +19,25 @@ tests :: [TF.Test]
 tests = [
         testGroup "EmailAddress Show/Read instances" [
                 testProperty "showLikeByteString" prop_showLikeByteString,
+                testProperty "showAndReadBackWithoutQuoteFails" prop_showAndReadBackWithoutQuoteFails,
                 testProperty "showAndReadBack" prop_showAndReadBack
                 ],
+
         testGroup "QuickCheck Text.Email.Validate" [
                 testProperty "doubleCanonicalize" prop_doubleCanonicalize
                 ],
+
         testGroup "Unit tests Text.Email.Validate" $ flip concatMap units
-            (\(em, valid, why) -> let email = BS.pack em
+            (\(em, valid, _) -> let email = BS.pack em
                 in
                     [
                     testCase ("doubleCanonicalize '" ++ em ++ "'") (True @=? case emailAddress email of { Nothing -> True; Just ok -> prop_doubleCanonicalize ok }),
                     testCase ("validity test '" ++ em ++ "'") (valid @=? isValid email)
-                    ])
+                    ]),
+
+        testGroup "Issues" [
+            testCase "#12" (let (Right em) = validate (BS.pack "\"\"@1") in em @=? read (show em))
+            ]
        ]
 
 instance Arbitrary ByteString where
@@ -40,15 +46,18 @@ instance Arbitrary ByteString where
 instance Arbitrary EmailAddress where
     arbitrary = do
         local <- suchThat arbitrary (\x -> isEmail x (BS.pack "example.com"))
-        domain <- suchThat arbitrary (\x -> isEmail (BS.pack "example") x)
+        domain <- suchThat arbitrary (isEmail (BS.pack "example"))
         let email = makeEmailLike local domain
         let (Just result) = emailAddress email
         return result
 
+isEmail :: ByteString -> ByteString -> Bool
 isEmail l d = isValid (makeEmailLike l d)
 
+makeEmailLike :: ByteString -> ByteString -> ByteString
 makeEmailLike l d = BS.concat [l, BS.singleton '@', d]
 
+prop_doubleCanonicalize :: EmailAddress -> Bool
 prop_doubleCanonicalize email =  Just email == emailAddress (toByteString email)
 
 prop_showLikeByteString :: EmailAddress -> Bool
@@ -57,8 +66,20 @@ prop_showLikeByteString email = show (toByteString email) == show email
 prop_showAndReadBack :: EmailAddress -> Bool
 prop_showAndReadBack email = read (show email) == email
 
+readMaybe :: String -> Maybe EmailAddress
+readMaybe s = case reads s of
+              [(x, "")] -> Just x
+              _ -> Nothing
+
+prop_showAndReadBackWithoutQuoteFails :: EmailAddress -> Bool
+prop_showAndReadBackWithoutQuoteFails email =
+    readMaybe (init s) == Nothing &&
+    readMaybe (tail s) == Nothing
+    where s = show email
+
 --unitTest (x, y, z) = if not (isValid (BS.pack x) == y) then "" else (x ++" became "++ (case emailAddress (BS.pack x) of {Nothing -> "fail"; Just em -> show em}) ++": Should be "++show y ++", got "++show (not y)++"\n\t"++z++"\n")
 
+units :: [(String, Bool, String)]
 units = [
     ("first.last@example.com", True, ""),
     ("1234567890123456789012345678901234567890123456789012345678901234@example.com", True, ""),
@@ -288,4 +309,4 @@ units = [
     --("first.last@com", False, "Mail host must be second- or lower level"),
     --("first.last@-xample.com", False, "Label can\'t begin with a hyphen"),
     --("first.last@exampl-.com", False, "Label can\'t end with a hyphen"),
-    ]
\ No newline at end of file
+    ]
